#include <pluginlib/class_list_macros.h>
#include <ros/ros.h>

#include "environment/Environment.h"
#include "exceptions/Exceptions.h"

#include "car/environmentDataMsg.h"

PLUGINLIB_EXPORT_CLASS(car::Environment, nodelet::Nodelet);

namespace car
{

Environment::Environment()
    : messageOStream(nh, "Environment")
      , distance(0)
      , relativeSpeed(0)
{}

void Environment::onInit()
{
    messageOStream << MessageOStream::key << "onInit()"
                   << MessageOStream::value << "START"
                   << MessageOStream::flush;

    environmentData = nh.advertise<environmentDataMsg>("environmentData", 1);
    ussData = nh.subscribe("ussData", 1, &Environment::ussDataCallback, this);
    camData = nh.subscribe("camData", 1, &Environment::camDataCallback, this);

    messageOStream << MessageOStream::key << "onInit()"
                   << MessageOStream::value << "END"
                   << MessageOStream::flush;
}

void Environment::ussDataCallback(const ussDataMsg::ConstPtr & inMsg)
{
    distance = inMsg->distance;
    relativeSpeed = 1.0;

    environmentDataMsg outMsg;
    outMsg.distance = distance;
    outMsg.relativeSpeed = relativeSpeed;

    environmentData.publish(outMsg);
}

void Environment::camDataCallback(const camDataMsg::ConstPtr & inMsg)
{
}

}
